@@ -141,20 +141,14 @@ NumExpr_init(NumExprObject *self, PyObject *args, PyObject *kwds)
                 itemsizes[i] = size_from_char('b');
                 continue;
             }
-#if PY_MAJOR_VERSION < 3
-            if (PyInt_Check(o)) {
-#else
+
             if (PyArray_IsScalar(o, Int32)) {
-#endif
                 PyBytes_AS_STRING(constsig)[i] = 'i';
                 itemsizes[i] = size_from_char('i');
                 continue;
             }
-#if PY_MAJOR_VERSION < 3
-            if (PyLong_Check(o)) {
-#else
+
             if (PyArray_IsScalar(o, Int64)) {
-#endif
                 PyBytes_AS_STRING(constsig)[i] = 'l';
                 itemsizes[i] = size_from_char('l');
                 continue;
@@ -411,4 +405,3 @@ PyTypeObject NumExprType = {
     0,                         /* tp_alloc */
     NumExpr_new,               /* tp_new */
 };
-
